@@ -1,5 +1,5 @@
 package JSON::Path::Evaluator;
-$JSON::Path::Evaluator::VERSION = '0.301';
+$JSON::Path::Evaluator::VERSION = '0.310';
 use strict;
 use warnings;
 use 5.008;
@@ -402,7 +402,7 @@ sub _process_perl {
 
     my $code = join '', @{$token_stream};
     my $cpt = Safe->new;
-    $cpt->permit_only( ':base_core', qw/padsv padav padhv padany/ );
+    $cpt->permit_only( ':base_core', qw/padsv padav padhv padany rv2gv/ );
     ${ $cpt->varglob('root') } = dclone( $self->{root} );
 
     my @matching;
@@ -460,7 +460,7 @@ JSON::Path::Evaluator - A module that recursively evaluates JSONPath expressions
 
 =head1 VERSION
 
-version 0.301
+version 0.310
 
 =head1 METHODS
 
